@@ -10,6 +10,8 @@
 #ifndef ILOCALIODEVICE_P_H
 #define ILOCALIODEVICE_P_H
 
+#include "api/api_global.h"
+
 //  -------------
 //  W A R N I N G
 //  -------------
@@ -25,26 +27,27 @@
 namespace BamTools {
 namespace Internal {
 
-class ILocalIODevice : public IBamIODevice {
+class API_NO_EXPORT ILocalIODevice : public IBamIODevice
+{
 
     // ctor & dtor
-    public:
-        ILocalIODevice(void);
-        virtual ~ILocalIODevice(void);
+public:
+    ILocalIODevice();
+    virtual ~ILocalIODevice();
 
     // IBamIODevice implementation
-    public:
-        virtual void Close(void);
-        virtual int64_t Read(char* data, const unsigned int numBytes);
-        virtual int64_t Tell(void) const;
-        virtual int64_t Write(const char* data, const unsigned int numBytes);
+public:
+    virtual void Close();
+    virtual int64_t Read(char* data, const unsigned int numBytes);
+    virtual int64_t Tell() const;
+    virtual int64_t Write(const char* data, const unsigned int numBytes);
 
     // data members
-    protected:
-        FILE* m_stream;
+protected:
+    FILE* m_stream;
 };
 
-} // namespace Internal
-} // namespace BamTools
+}  // namespace Internal
+}  // namespace BamTools
 
-#endif // ILOCALIODEVICE_P_H
+#endif  // ILOCALIODEVICE_P_H
