@@ -4,7 +4,7 @@
 // ---------------------------------------------------------------------------
 // Last modified: 1 August 2010
 // ---------------------------------------------------------------------------
-// Prints coverage data for a single BAM file 
+// Prints coverage data for a single BAM file
 // ***************************************************************************
 
 #ifndef BAMTOOLS_COVERAGE_H
@@ -13,25 +13,26 @@
 #include "bamtools_tool.h"
 
 namespace BamTools {
-  
-class CoverageTool : public AbstractTool {
-  
-    public:
-        CoverageTool(void);
-        ~CoverageTool(void);
-  
-    public:
-        int Help(void);
-        int Run(int argc, char* argv[]); 
-        
-    private:  
-        struct CoverageSettings;
-        CoverageSettings* m_settings;
-        
-        struct CoverageToolPrivate;
-        CoverageToolPrivate* m_impl;
-};
-  
-} // namespace BamTools
 
-#endif // BAMTOOLS_COVERAGE_H
+class CoverageTool : public AbstractTool
+{
+
+public:
+    CoverageTool();
+    ~CoverageTool();
+
+public:
+    int Help();
+    int Run(int argc, char* argv[]);
+
+private:
+    struct CoverageSettings;
+    CoverageSettings* m_settings;
+
+    struct CoverageToolPrivate;
+    CoverageToolPrivate* m_impl;
+};
+
+}  // namespace BamTools
+
+#endif  // BAMTOOLS_COVERAGE_H
