@@ -540,22 +540,18 @@ const std::string FilterTool::FilterToolPrivate::GetScriptContents()
     // read in entire script contents
     char buffer[1024];
     std::ostringstream docStream;
-    while (true) {
-
-        // peek ahead, make sure there is data available
-        char ch = fgetc(inFile);
-        ungetc(ch, inFile);
-        if (feof(inFile)) {
+    while (!feof(inFile)) {
+        // read next block of data
+        const char* data = fgets(buffer, sizeof(buffer), inFile);
+        if (!data) {
             break;
         }
-
-        // read next block of data
-        if (fgets(buffer, 1024, inFile) == 0) {
+        if (ferror(inFile)) {
             std::cerr << "bamtools filter ERROR: could not read script contents" << std::endl;
-            return std::string();
+            return {};
         }
 
-        docStream << buffer;
+        docStream << data;
     }
 
     // close script file
@@ -1020,7 +1016,7 @@ FilterTool::FilterTool()
     const std::string isFirstMateDesc = "keep only alignments marked as first mate?";
     const std::string isMappedDesc = "keep only alignments that were mapped?";
     const std::string isMateMappedDesc = "keep only alignments with mates that mapped";
-    const std::string isMateReverseDesc = "keep only alignments with mate on reverese strand?";
+    const std::string isMateReverseDesc = "keep only alignments with mate on reverse strand?";
     const std::string isPairedDesc = "keep only alignments that were sequenced as paired?";
     const std::string isPrimaryDesc = "keep only alignments marked as primary?";
     const std::string isProperPairDesc = "keep only alignments that passed PE resolution?";
