@@ -52,6 +52,7 @@ struct Fasta::FastaPrivate
     bool CreateIndex(const std::string& indexFilename);
     bool GetBase(const int& refId, const int& position, char& base);
     bool GetSequence(const int& refId, const int& start, const int& stop, std::string& sequence);
+    bool GetLength(const int& refId, int& length);
     bool Open(const std::string& filename, const std::string& indexFilename);
 
     // internal methods
@@ -174,7 +175,6 @@ bool Fasta::FastaPrivate::CreateIndex(const std::string& indexFilename)
     }
 
     // iterate through fasta entries
-    int currentId = 0;
     std::string header;
     std::string sequence;
     while (GetNextHeader(header)) {
@@ -206,9 +206,6 @@ bool Fasta::FastaPrivate::CreateIndex(const std::string& indexFilename)
 
         // store index entry
         Index.push_back(data);
-
-        // update ref Id
-        ++currentId;
     }
 
     // open index file
@@ -509,6 +506,26 @@ bool Fasta::FastaPrivate::GetSequence(const int& refId, const int& start, const
     return true;
 }
 
+bool Fasta::FastaPrivate::GetLength(const int& refId, int& length)
+{
+    // make sure FASTA file is open
+    if (!IsOpen) {
+        std::cerr << "FASTA error : file not open for reading\n";
+        return false;
+    }
+
+    // make sure index if available
+    if (!HasIndex && Index.empty()) {
+        std::cerr << "FASTA error : could not read from index file\n";
+        return false;
+    }
+
+    length = Index.at(refId).Length;
+
+    // return success
+    return true;
+}
+
 bool Fasta::FastaPrivate::LoadIndexData()
 {
 
@@ -670,3 +687,8 @@ bool Fasta::Open(const std::string& filename, const std::string& indexFilename)
 {
     return d->Open(filename, indexFilename);
 }
+
+bool Fasta::GetLength(const int& refId, int& length)
+{
+    return d->GetLength(refId, length);
+}
